Package 'icd.data'

Title: International Classifcation of Diseases (ICD) Data
Description: Data from the United States Center for Medicare and Medicaid Services (CMS) is included in this package. There are ICD-9 and ICD-10 diagnostic and procedure codes, and lists of the chapter and sub-chapter headings and the ranges of ICD codes they encompass. There are also two sample datasets. These data are used by the 'icd' package for finding comorbidities.
Authors: Jack O. Wasey [aut, cre, cph]
Maintainer: Jack O. Wasey <[email protected]>
License: GPL-3
Version: 1.0
Built: 2026-06-04 09:51:53 UTC
Source: https://github.com/cran/icd.data

Help Index


icd.data: International Classifcation of Diseases (ICD) Data

Description

Data from the United States Center for Medicare and Medicaid Services (CMS) is included in this package. There are ICD-9 and ICD-10 diagnostic and procedure codes, and lists of the chapter and sub-chapter headings and the ranges of ICD codes they encompass. There are also two sample datasets. These data are used by the 'icd' package for finding comorbidities.

Author(s)

Jack O. Wasey [email protected]


ICD-10 chapters

Description

The WHO ICD-10 scheme chapters. The chapter level is the highest in the hierarchy, each chapter containing sets of codes which span multiple three-digit 'major' codes, and in some cases also span codes across two alphabetic initial characters. E.g. Chapter I spans A00 to B99.

Details

2017 ICD-10-CM does not have any U codes (codes for special purposes). U00-U49 - Provisional assignment of new diseases of uncertain etiology or emergency use U82-U85 - Resistance to antimicrobial and anti-neoplastic drugs

Format: list with chapter names stored in list names, each with two element named character vector with start and end codes.

http://apps.who.int/classifications/icd10/browse/2016/en


AHRQ ICD-10-PCS categories

Description

The AHRQ has categorized each of the ICD-10-PCS (Procedure Codes) into one of four groups: minor diagnostic, minor therapeutic, major diagnostic or major therapeutic. This mapping can be used to get the type(s) of procedure(s) performed on a patient from a data.frame of patients and associated procedure codes in 'long' format. See the ICD-10 vignette for an example.

See Also

https://www.hcup-us.ahrq.gov/toolssoftware/procedureicd10/procedure_icd10.jsp


ICD-10-CM Procedure Codes

Description

ICD-10-PCS is the annually-updated set of procedure codes designed by 3M for the US CMS. There is no directory of WHO ICD procedure codes.

Details

Format: A named list of data frames. The elements of the list are named by the year, e.g., "2018". Each data frame contains two character columns, the first, named code is the procedure code; the second, named desc, has the description.

See Also

https://www.cms.gov/Medicare/Coding/ICD10/downloads/pcs_refman.pdf


ICD-10 sub-chapters

Description

The WHO ICD-10 scheme sub-chapters. N.b. there may be WHO vs CM differences: please file bug if noted. In the XML definition of ICD-10-CM there are some intermediate hierarchical levels, e.g. for neoplasms. Sub-chapter here is defined as the lowest-level grouping of three-digit codes, e.g. C00-C14 "Malignant neoplasms of lip, oral cavity and pharynx", not C00-C96 "Malignant neoplasms" which itself is a subset of the chapter C00-D49 "Neoplasms"

Details

Format: list with sub-chapter or major names stored in list names, each with two element named character vector with start and end codes.

http://apps.who.int/classifications/icd10/browse/2016/en


ICD-10-CM

Description

The public domain modified ICD-10 classification as published in the public domain by the US CDC. Currently this has a slightly different structure to icd9cm_hierarchy because the published data helpfully has a leaf flag indicating whether a code is a billable leaf node, or a code higher in the hierarchy which nevertheless will have a description.

Details

There are annual revisions to this data. Currently, the 2016 edition is included.

Format: data frame, with columns for code, leaf status (0 or 1), short and long descriptions.

http://www.cdc.gov/nchs/icd/icd10cm.htm


ICD-9 chapters

Description

icd9_chapters, icd9_chapters_sub and icd9_majors contain mappings from the higher level descriptions of ICD-9 codes to the ranges of ICD-9 codes they describe. Helpful in summarizing codes or grouping for human-readable output. These can easily be converted to a co-morbidity mapping, as shown in the vignette.

Details

  • 001-139 Infectious And Parasitic Diseases

  • 140-239 Neoplasms

  • 240-279 Endocrine, Nutritional And Metabolic Diseases, And Immunity Disorders

  • 280-289 Diseases Of The Blood And Blood-Forming Organs

  • 290-319 Mental Disorders

  • 320-389 Diseases Of The Nervous System And Sense Organs

  • 390-459 Diseases Of The Circulatory System

  • 460-519 Diseases Of The Respiratory System

  • 520-579 Diseases Of The Digestive System

  • 580-629 Diseases Of The Genitourinary System

  • 630-679 Complications Of Pregnancy, Childbirth, And The Puerperium

  • 680-709 Diseases Of The Skin And Subcutaneous Tissue

  • 710-739 Diseases Of The Musculoskeletal System And Connective Tissue

  • 740-759 Congenital Anomalies

  • 760-779 Certain Conditions Originating In The Perinatal Period

  • 780-799 Symptoms, Signs, And Ill-Defined Conditions

  • 800-999 Injury And Poisoning

  • V01-V91 Supplementary Classification Of Factors Influencing Health Status And Contact With Health Services

  • E000-E999 Supplementary Classification Of External Causes Of Injury And Poisoning

Format: list with chapter/sub-chapter or major names stored in list names, each with two element named character vector with start and end codes.

http://www.cms.gov/Medicare/Coding/ICD9ProviderDiagnosticCodes/codes.html


list of annual versions of billable leaf nodes of ICD-9-CM

Description

These are derived from the CMS published updates, with versions 23 to 32 currently available going back to 2004/5. The source files back to version 27 have short and long descriptions. The short descriptions are in ASCII with no special characters, whereas the long descriptions contain accented characters which seem to be interpreted as Unicode, latin-1 or cp1252. This all done during package creation, but can be repeated by package users, including pulling the data from the web pages directly. Despite my best efforts, current locale can give different results, but this packaged data is correct, with some UTF-8 encoded strings.

Details

Format: list of data frames. Each list item is named by the version as a string, e.g. "32". The constituent data frames have columns icd9, shortDesc, and longDesc.

http://www.cms.gov/Medicare/Coding/ICD9ProviderDiagnosticCodes/codes.html


List the data in this package

Description

List the data in this package

Usage

ls_icd_data()

Examples

## Not run: 
ls_icd_data()

## End(Not run)

United States Transuranium & Uranium Registries

Description

an ICD-10 data set (not ICD-10-CM) with mortality from the United States Transuranium & Uranium Registries, published in the public domain.

https://ustur.wsu.edu/about-us/


Hospital discharge data from Vermont

Description

Anonymous data from public Vermont source for 2013

Details

Conditions of Release Release of public use data is subject to the following conditions, which the requestor agrees to upon accepting copies of the data:

1. The data may not be used in any manner that attempts to or does identify, directly or indirectly, any individual patient or physician.

2. The requestor agrees to incorporate the following, or a substantially similar, disclaimer in all reports or publications that include public use data: "Hospital discharge data for use in this study were supplied by the Vermont Association of Hospitals and Health Systems-Network Services Organization (VAHHS-NSO) and the Vermont Department of Banking, Insurance, Securities and Health Care Administration (BISHCA). All analyses, interpretations or conclusions based on these data are solely that of [the requestor]. VAHHS-NSO and BISHCA disclaim responsibility for any such analyses, interpretations or conclusions. In addition, as the data have been edited and processed by VAHHS-NSO, BISHCA assumes no responsibility for errors in the data due to coding or processing"

Format: CSV original, minimally processed into R data frame.

Author(s)

Vermont Division of Health Care Administration

http://www.healthvermont.gov/health-statistics-vital-records/health-care-systems-reporting/hospital-discharge-data